Additional Examples
===================

.. toctree::
   :maxdepth: 1

   quantile_regression_example
   binary_target_with_custom_wrapper_example
   boosted_linear_model_example
   alternative_fitting_procedure_example
   forward_neural_network_example
